diff src/ntheap.c @ 5384:3889ef128488

Fix misspelled words, and some grammar, across the entire source tree. See xemacs-patches message with ID <AANLkTi=edkEKtK3pZ60ytsG5pTJQy2TjAEVCZCLOa-oA@mail.gmail.com>.
author Jerry James <james@xemacs.org>
date Thu, 24 Mar 2011 11:00:11 -0600
parents ecf1ebac70d8
children 4dee0387b9de
line wrap: on
line diff
--- a/src/ntheap.c	Thu Mar 24 06:22:25 2011 +0000
+++ b/src/ntheap.c	Thu Mar 24 11:00:11 2011 -0600
@@ -245,7 +245,7 @@
   VirtualQuery (base, &info, sizeof (info));
   if (info.State != MEM_FREE)
     {
       /* Oops, something has already reserved or commited it, nothing
 	 we can do but exit */
       Extbyte buf[256];
       sprintf (buf,
@@ -254,7 +254,7 @@
 	       "(BaseAddress = 0x%lx, AllocationBase = 0x%lx, "
 	       "Size = 0x%lx, State = %s, Type = %s)",
 	       info.BaseAddress, info.AllocationBase, info.RegionSize,
-	       info.State == MEM_COMMIT ? "COMMITED" : "RESERVED",
+	       info.State == MEM_COMMIT ? "COMMITTED" : "RESERVED",
 	       info.Type == MEM_IMAGE ? "IMAGE" :
 	       info.Type == MEM_MAPPED ? "MAPPED" : "PRIVATE");
       MessageBoxA (NULL, buf, "XEmacs", MB_OK | MB_ICONSTOP);
@@ -245,7 +245,7 @@
   if (info.State != MEM_FREE)
     {
-      /* Oops, something has already reserved or commited it, nothing
+      /* Oops, something has already reserved or committed it, nothing
 	 we can do but exit */
       Extbyte buf[256];